define(function(require, exports, module) {
	'use strict';
	var util = require("util");
	var base = require("base");
	var databind = require("databind");
	var listView = require("listView");
	var router = require("pageRouter");
	var dialog = require("dialog");
	var constant = require("constant");
	var dom;

	var init = function() {
		dom = $("#page-home");

		initJuicer();
		loadData();
		loadStudentName();
	};

	var initJuicer = function() {
		initClickEvent();
		juicer.register("fsPath", function() {
			return CONFIG.fsPath;
		});

		juicer.register("getValueByKey", constant.getValueByKey);
	};

	var loadData = function() {
        var schoolTimeTableDeferred = loadTimeTable();
		var schedulingDeferred = loadScheduling();

		$.when(schoolTimeTableDeferred, schedulingDeferred).done(function(schoolTimeTable, scheduling) {
			if (scheduling.length == 0) {
				dom.find(".empty-view").show();
				return;
			}

			//构建课程表框架
            dom.find('.kcb-container').html(juicer(dom.find('script[data-tmpl-name=kcb]').html(),{datas: schoolTimeTable}));

            var cd = new Date();
            dom.find("[data-wd="+cd.getDay()+"]").addClass("todayisbeautifulday");

            //填充数据
            for(var index in scheduling) {
                var l = scheduling[index];
                appendKcbItem(dom.find("[pos="+l.workDay+"-"+l.classSection+"]>div"),l);
            }
		});
	};

    function loadStudentName(){
        databind.submit([], {
            action: 'inquireCurrentStudentInfoAccount',
            data: {},
            success:function(ret) {
                dom.find('.page-header .title').text(ret.datas[0].studentName+"的课程表");
            }
            });
	}
	function loadTimeTable(){
    	var schoolTimeTableDeferred = $.Deferred();

        databind.submit([],{
            action:'inquireCurrentScheduleTimeTableListTenant',
            success:function(ret){
            	schoolTimeTableDeferred.resolve(ret.datas);
            }
        });

        return schoolTimeTableDeferred;
	}

	function loadScheduling(){
		var schedulingDeferred = $.Deferred();

		databind.submit([],{
			action:'inquireCourseScheduleListStudentAccount',
			data:{semesterCode: '20171'},
			success:function(ret){
                schedulingDeferred.resolve(ret.datas);
			}
		});
		return schedulingDeferred;
	}

	function appendKcbItem(dd,data){
        base.adaptHeight(dom);
		var exists = dd.find(".course-item");
		if(exists.length){
			return ;
		}
		dd.append(juicer(dom.find("script[data-tmpl-name=course-kcb]").html(),data));
		var chs  = dd.children();
		chs.each(function(idx,itm){
			$(itm).css("width",(100/chs.length)+"%").css("float","left");
		});

	}

	function initClickEvent(){
		dom.on('click','.course-item',function(){
			var th  = $(this);
			var ptd = th.parents('td');
			var wds = ['','星期一','星期二','星期三','星期四','星期五'];

			dialog.loadDialog('course.dialog-scheduling',{
				params:{html:juicer(dom.find('script[data-tmpl-name=detailDialog]').html(),{
					// se_name:wds[parseInt(ptd.attr('data-se'))],
                    se_name:wds[parseInt(ptd.attr('data-se'))],
					se:ptd.attr('data-se-pi'),
					se_dt:ptd.attr('data-se-dt'),
					courseName:th.find('.courseName').text(),
                    className:th.find('.className').text(),
					teacherNameList:th.find('[name=teacherNameList]').val(),
					placeNameList:th.find('[name=placeNameList]').val()
				})}
			},'');
		});
	}



	return {
		init: init
	};
});
