;
define(function(require, exports, module) {
	'use strict';
	var util = require("util");
	var base = require("base");
	var validator = require("validate");
	var constant = require("constant");

	var formatDate = function(date, format) {
		if(!date) return;
		if(!format) format = "yyyy/MM/dd";
		switch(typeof date) {
			case "string":
				date = new Date(date.replace(/-/g, "/"));
				break;
			case "number":
				date = new Date(date);
				break;
		}
		if(!date instanceof Date) return;
		var dict = {
			"yyyy": date.getFullYear(),
			"M": date.getMonth() + 1,
			"d": date.getDate(),
			"H": date.getHours(),
			"m": date.getMinutes(),
			"s": date.getSeconds(),
			"MM": ("" + (date.getMonth() + 101)).substr(1),
			"dd": ("" + (date.getDate() + 100)).substr(1),
			"HH": ("" + (date.getHours() + 100)).substr(1),
			"mm": ("" + (date.getMinutes() + 100)).substr(1),
			"ss": ("" + (date.getSeconds() + 100)).substr(1)
		};
		return format.replace(/(yyyy|MM?|dd?|HH?|ss?|mm?)/g, function() {
			return dict[arguments[0]];
		});
	};
	
	var ruleDate = function(date) {
		var nowDate = new Date();
		var nowYear = nowDate.getFullYear();
		var nowMonth = nowDate.getMonth();
		var nowDay = nowDate.getDate();
		var parameterDt = new Date(date.replace(/-/g, "/"));
		if(parameterDt.getFullYear() == nowYear) {
			if(parameterDt.getMonth() == nowMonth && parameterDt.getDate() == nowDay) {
				return formatDate(date, "HH:mm");
			} else {
				return formatDate(date, "MM-dd HH:mm");
			}
		} else {
			return formatDate(date, "yyyy-MM-dd HH:mm");
		}
	};
	
 	var dateCompute = function(interval) {
 		var now = new Date(); //当前日期 
		var nowDayOfWeek = now.getDay(); //今天本周的第几天 
		var nowDay = now.getDate(); //当前日
		var nowMonth = now.getMonth(); //当前月 
		var nowYear = now.getFullYear(); //当前年
		var lastMonthDate = new Date(); //上月日期
		lastMonthDate.setDate(1);
		lastMonthDate.setMonth(lastMonthDate.getMonth()-1);
		var lastYear = lastMonthDate.getYear();
		var lastMonth = lastMonthDate.getMonth();
		
		switch (interval) {
		    case "y": {
		        return new Date(nowYear, 0, 1);
		        break;
		    }
		    case "1/2y": {
		    	return new Date(nowYear, nowMonth - 5, 1);
		        break;
		    }
		    case "3m": {
		    		return new Date(nowYear, nowMonth - 2, 1);
		        break;
		    }
		    case "m": {
		        return new Date(nowYear, nowMonth, 1);
		        break;
		    }
		    case "w": {
		    	var weekday = nowDayOfWeek||7;
		    	return new Date(nowYear, nowMonth, nowDay - weekday + 1);
		        break;
		    }
	    }
 	};
	
	return {
		formatDate: formatDate,
		ruleDate: ruleDate,
		dateCompute: dateCompute
	};
});