define(function(require, exports, module) {
	'use strict';
	var util = require("util");
	var base = require("base");
	var databind = require("databind");
	var listView = require("listView");
	var router = require("pageRouter");
	var dialog = require("dialog");
	var constant = require("constant");
	var timeFormat = require("timeFormat");
	var dom;
	var pageSize = 10;
	var undoPageIndex;
	var pageIndex;

	var init = function() {
		dom = $("#leave-record");
		$("body").removeClass("overflowHidden");
		$("body").removeClass("noScoll");
		router.init();
		initJuicer();
		initEvent();
		pageIndex = 1;
		loadData(pageIndex);		
	};
	var initJuicer = function() {
		juicer.register("getValueByKey", constant.getValueByKey);
		juicer.register("getShowDate", function(date) {
			return timeFormat.getShowDate(date);
		});
		
		juicer.register("getDateFormat", function(date) {
			return timeFormat.formatDate(date, "yyyy-MM-dd HH:mm");
		});

        juicer.register("getcode", function(fileName) {
            return encodeURIComponent(fileName);
        });
	}
	var initEvent = function() {
		$(".backBtn").unbind().bind("click", back);
		//详情撤回
		dom.on("click", ".withdraw", function() {
			var leaveId = $(this).parent("div").parent("div").parent(".leaveDetailPart").attr("leaveId");
			/*var leaveId=2;*/
			dialog.loadDialog("dialog.confirmDialog", {
				params: {					
					tips: "确认撤销该份请假单吗?"					
				},
				okFn: function() {
					databind.submit([], {
						action: "cancelLeaveSAAccount",
						version: "v1.0",
						data: {
							leaveId: leaveId
						},
						success: function() {
							base.alert(2, "撤销成功");
							dialog.hideDialog();
							pageIndex = 1;
							loadData(pageIndex);
						},
						fail: function(error) {
							base.alert(2,error.message);
							loadData(1);
							dialog.hideDialog();
						}
					});
				}
			}, "small");
		});

		//点击编辑
		dom.on("click", ".edit", function() {
			var leaveId = $(this).parent("div").parent("div").parent(".leaveDetailPart").attr("leaveId");
			router.route("#parent.create-leave?leaveId=" + leaveId);

		});

		//点击删除
		dom.on("click", ".delete", function() {
			var leaveId = $(this).parent("div").parent("div").parent(".leaveDetailPart").attr("leaveId");
			dialog.loadDialog("dialog.confirmDialog", {
				params: {
					
					tips: "确认删除该份请假单吗?"
					
				},
				okFn: function() {
					databind.submit([], {
						action: "deleteLeaveSAAccount",
						version: "v1.0",
						data: {
							leaveId: leaveId
							
						},
						success: function() {
							base.alert(2, "删除成功");
							dialog.hideDialog();
							pageIndex = 1;
							loadData(pageIndex);
						}
					});
				}
			}, "small");
		});
		/*	点击确认*/
		dom.on("click", ".confirm", function() {
			var leaveId = $(this).parent("div").parent(".leaveDetailPart").attr("leaveId");
			databind.submit([], {
						action: "ensureLeaveBatchSAAccount",
						version: "v1.0",
						data: {
							leaveId: leaveId
							
						},
						success: function() {
							base.alert(2, "确认成功");
							pageIndex = 1;
							loadData(pageIndex);
						}
					});

		});
		/*点击退回*/
		dom.on("click", ".return", function() {
			var leaveId = $(this).parent("div").parent(".leaveDetailPart").attr("leaveId");
			dialog.loadDialog("dialog.confirmDialog", {
				params: {
					
					tips: "确认退回该份请假单吗?"
					
				},
				okFn: function() {
					databind.submit([], {
						action: "sendBackLeaveSAAccount",
						version: "v1.0",
						data: {
							leaveId: leaveId
							
						},
						success: function() {
							base.alert(2, "退回成功");
							dialog.hideDialog();
							pageIndex = 1;
							loadData(pageIndex);
						}
					});
				}
			}, "small");
		});
		/*填写请假条*/
		dom.find(".bottomBtn").on("click",function(){
			router.route("#parent.create-leave");
		});
		
		//列表加载下一页
		$(".load-more").on("click", function() {
			pageIndex ++;
			loadData(pageIndex);
		});

		//重新绑定实体按键返回事件
		window._android_on_back_pressed = function() {
			back();
			return false;
		}
	}

	var back = function() {
		var source = base.getUrlParam("source");
		if(source) {
			base.close();
			return false;
		}
		base.back();
		return false;
	}
	
	var loadData = function(pageIndex) {
		databind.submit([], {
			action: "inquireLeaveListParentSAAccount",
			version: "v1.0",
			data: {
				pageIndex: pageIndex,
				pageSize: pageSize
			},
			success: function(data) {
				if(pageIndex == 1) {
					dom.find(".common-item-list").empty();	
				}
				
				var html = juicer(dom.find("#doneListTpl").html(), data);
				dom.find(".common-item-list").append(html);
				
				console.log(data.datas.length);
				if(data.datas.length != 0) {
					var totalLeaveListCount = data.datas[0].totalLeaveListCount;
					if(totalLeaveListCount) {
						if(pageIndex < Math.ceil(totalLeaveListCount / pageSize)) {
							$(".load-more").attr("disabled", false);
							$(".load-more").val("点击加载更多");
						} else {
							$(".load-more").attr("disabled", true);
							$(".load-more").val("已加载全部");
						}
					}
					
					dom.find(".load-more").attr("type", "button");
				} else {
					dom.find(".load-more").attr("type", "hidden");
				}
				
				var semesterCodeList = new Array();
				if(data.datas.length) {
					for(var i = 0; i < data.datas.length; i++) {
						semesterCodeList.push("code" + data.datas[i].semesterCode);
					}
					for(var i = 0; i < semesterCodeList.length; i++) {
						dom.find("." + semesterCodeList[i] + ":first").removeClass("none");
					}
				} else {
					dom.find(".container-searchbox").removeClass("none");
				}
			},
			fail: function(error) {
				base.alert(3, "请求失败,请检查网络连接");
			}
		});		
	}

return {
	init: init
};
});