// 主界面
;
define(function (require, exports, module) {
  'use strict';
  var util = require("util");
  var base = require("base");
  var databind = require("databind");
  var listView = require("listView");
  var router = require("pageRouter");
  var dialog = require("dialog");
  var constant = require("constant");
  var readingUtil = require("readingUtil");
  var dom;
  var bookId;
  var postType;
  var filtrationType;
  var onlyShowExcellence;
  var pageIndex = 1;
  var deleteDom;

  var init = function (tBookId, tPostType, tFiltrationType, tOnlyShowExcellence) {
    dom = $("#book-detail-post");
    router.init();
    initEvent();
    initJuicer();
    bookId = tBookId;
    postType = tPostType;
    filtrationType = tFiltrationType;
    onlyShowExcellence = tOnlyShowExcellence;
    loadData();
  };

  var initEvent = function () {
    var height = window.screen.height;
    if (height > 640){
      dom.find(".container-loadList").css("min-height", "280px");
    }

    document.addEventListener('visibilitychange', function () {
      if (document.hidden) {
        stopAllAudio();
      }
    });

    //操作菜单栏
    dom.on("click", ".headerRight", function(e){
      if ($(this).find(".edit").hasClass("none")) {
        $(this).find(".edit").removeClass("none");
      }else{
        $(this).find(".edit").addClass("none");
      }
      e.stopPropagation();
    });

    //删除
    dom.on("click", ".delete-post", function (e) {
      var postId = $(this).attr("postId");
      deleteDom = $(this).parents(".postContent");
      dialog.loadDialog("dialog.confirmDialog", {
        params: {
          tips: "确定删除该作品吗？"
        },
        okFn: function () {
          databind.submit([], {
            action: "deleteReadingPostStudentAccount",
            version: "v1.0",
            data: {
              postId: postId
            },
            success: function (data) {
              base.alert(1,"删除成功");
              dialog.hideDialog();
              deleteDom.remove();
            }
          });
        }
      }, "medium");
      e.stopPropagation();
    });

    //悦读圈图片预览
    dom.on("click", ".book-detail-post-img", function (e) {
      var uuidArr = [];
      var idx = $(this).attr("index");
      if ($(this).hasClass("w")){
        $(this).parent().parent().parent().find(".book-detail-post-img").each(function (idx, item) {
          var fileUuid = $(this).attr("fileUuid");
          uuidArr.push(fileUuid);
        });
      } else {
        $(this).parent().find(".book-detail-post-img").each(function (idx, item) {
          var fileUuid = $(this).attr("fileUuid");
          uuidArr.push(fileUuid);
        });
      }
      base.callGallery(uuidArr, idx);
      e.stopPropagation();
    });

    //悦读圈点击帖子进详情（复用发现页的帖子详情）
    dom.on("click", ".postContent", function () {
      var postId = $(this).attr("postId");
      base.openUrl("index.html#studentPage.discovery-detail?postId=" + postId, "YX_READING_STUDENT_APP");
    });

    //录音播放
    dom.on("click", ".audioPlayer", function (e) {
      //重置当前页面所有audio（除点击的这个）为停止播放状态，且播放时间归零
      var allAudioList = $(".content").find('audio');
      for (var i = 0; i < allAudioList.length; i++) {
        var audioItem = allAudioList[i];
        if (audioItem == $(this).find('audio')[0]) {
          continue;
        }
        audioItem.pause();
        audioItem.currentTime = 0;
        $(audioItem).parent().find(".record-icon").attr("src","./res/images/icon/icon_record.png");
      }
      var audio = $(this).find('audio')[0];
      audio.loop = false;
      audio.onpause = function () {
        $(this).parent().find(".record-icon").attr("src","./res/images/icon/icon_record.png");
      };
      if (audio.paused) {
        // 开始播放当前点击的音频
        audio.play();
        audio.onended = function () {
          $(this).parent().find(".record-icon").attr("src","./res/images/icon/icon_record.png");
        };
        $(this).parent().find(".record-icon").attr("src","./res/images/icon/icon_record_playing.gif");
      } else {
        audio.pause();
        audio.currentTime = 0;
        $(this).parent().find(".record-icon").attr("src","./res/images/icon/icon_record.png");
      }
      e.stopPropagation();
    });

    //点赞
    dom.on("click", ".thumb", function (e) {
      var postId = $(this).attr("postId");
      var thumbUpDiv = $(this).find(".thumbUp");
      thumbUpReadingPostAccount(postId, thumbUpDiv);
      e.stopPropagation();
    });

    dom.on("click", ".headToInfo", function(e){
      stopAllAudio();
      var studentId = $(this).attr("studentId");
      var schoolId = $(this).attr("schoolId");
      base.openUrl("index.html#studentPage.personal?studentId="+studentId+"&schoolId="+schoolId,"");
      e.stopPropagation();
    });

    //更多
    dom.on("click", ".more", function(){
      loadMoreData();
    });
  };

  var initJuicer = function () {
    juicer.register("getReadingLevel", function (level) {
      return readingUtil.getReadingLevelDom(level);
    });

    juicer.register("fsPath", function () {
      return CONFIG.fsPath;
    });

    juicer.register("decode", function (replyContent) {
      return uncodeUtf16(decodeURIComponent(replyContent));
    });
  };

  var loadData = function () {
    //悦读圈
    databind.submit([], {
      action: "inquireReadingPostListByBookIdAccount",
      version: "v1.0",
      data: {
        bookId: bookId,
        postType:postType,
        filtrationType:filtrationType,
        onlyShowExcellence:onlyShowExcellence
      },
      success: function (data) {
        //计算帖子内容一行容纳多少个字
        var oneLineMaxWordsNum = parseInt(($(".content").width() - 25) / 15);

        for (var i = 0; i < data.datas.length; i++) {
          var dic = data.datas[i];
          var imgArr = dic.imageAttachmentUuid.split(",");
          var audioTime = transTime(dic.audioTime);
          dic.imgArr = imgArr;
          dic.audioTime = audioTime;

          if (uncodeUtf16(decodeURIComponent(dic.postContent)).length > oneLineMaxWordsNum * 4) {
            dic.postContent = uncodeUtf16(decodeURIComponent(dic.postContent)).substring(0, (oneLineMaxWordsNum * 4 - 6)) + "...";
            dic.showFullTextBtn = 1;
          }else {
            dic.postContent = uncodeUtf16(decodeURIComponent(dic.postContent));
          }
          data.datas[i] = dic;

        }
        var html = juicer(dom.find("#post-tpl").html(), data);
        dom.find(".content").html(html);

        if (data.totalPageCount > pageIndex) {
          dom.find(".more").removeClass("none");
        }else{
          dom.find(".more").addClass("none");
        }
        if (data.datas.length == 0){
          dom.find(".nodata").removeClass("none");
          dom.find(".content").css("padding-bottom","0px");
        }else {
          dom.find(".nodata").addClass("none");
          //50px 是为了最后底下一条帖子不被"+"按钮挡住
          dom.find(".content").css("padding-bottom","70px");
        }

        adaptiveImageHeight();
      }
    });
  };

  var loadMoreData = function () {
    pageIndex++;
    databind.submit([], {
      action: "inquireReadingPostListByBookIdAccount",
      version: "v1.0",
      data: {
        bookId: bookId,
        postType:postType,
        filtrationType:filtrationType,
        onlyShowExcellence:onlyShowExcellence,
        pageIndex:pageIndex,
        page: 20
      },
      success: function (data) {
        dom.find(".more").remove();
        //计算帖子内容一行容纳多少个字
        var oneLineMaxWordsNum = parseInt(($(".content").width() - 25) / 15);

        for (var i = 0; i < data.datas.length; i++) {
          var dic = data.datas[i];
          var imgArr = dic.imageAttachmentUuid.split(",");
          var audioTime = transTime(dic.audioTime);
          dic.imgArr = imgArr;
          dic.audioTime = audioTime;

          if (uncodeUtf16(decodeURIComponent(dic.postContent)).length > oneLineMaxWordsNum * 4) {
            dic.postContent = uncodeUtf16(decodeURIComponent(dic.postContent)).substring(0, (oneLineMaxWordsNum * 4 - 6)) + "...";
            dic.showFullTextBtn = 1;
          }else {
            dic.postContent = uncodeUtf16(decodeURIComponent(dic.postContent));
          }
          data.datas[i] = dic;

        }
        var html = juicer(dom.find("#post-tpl").html(), data);
        dom.find(".content").append(html);

        if (data.totalPageCount > pageIndex) {
          dom.find(".more").removeClass("none");
        }else{
          dom.find(".more").addClass("none");
        }
        if (data.datas.length == 0){
          dom.find(".nodata").removeClass("none");
          dom.find(".content").css("padding-bottom","0px");
        }else {
          dom.find(".nodata").addClass("none");
          //50px 是为了最后底下一条帖子不被"+"按钮挡住
          dom.find(".content").css("padding-bottom","70px");
        }

        adaptiveImageHeight();
      }
    });
  };

  var adaptiveImageHeight = function () {
    $(".img-overflow-style").css("height", $(".img-width-control").width() + "px");
    $(".img-overflow-style").css("line-height", $(".img-width-control").width() + "px");
  };

  var thumbUpReadingPostAccount = function (postId, thumbUpDiv) {
    databind.submit([], {
      action: "thumbUpReadingPostStudentAccount",
      version: "v1.0",
      async: false,
      data: {
        postId: postId
      },
      success:function(){
        var thumbUp = thumbUpDiv.attr("thumbUp");
        var count = thumbUpDiv.parent().find(".thumbUpCount").text();
        if (thumbUp == "1"){
          thumbUpDiv.attr("src","./res/png/thumbUp_gray.png");
          thumbUpDiv.attr("thumbUp", "0");
          thumbUpDiv.parent().find(".thumbUpCount").text(parseInt(count)-1);
        } else {
          thumbUpDiv.attr("src","./res/png/thumbUp.png");
          thumbUpDiv.attr("thumbUp", "1");
          thumbUpDiv.parent().find(".thumbUpCount").text(parseInt(count)+1);
        }
      }
    });
  };

  /**
   * 音频播放时间换算
   * @param {number} value - 音频当前播放时间，单位秒
   */
  var transTime = function (value) {
    var time = "";
    var h = parseInt(value / 3600);
    value %= 3600;
    var m = parseInt(value / 60);
    var s = parseInt(value % 60);
    if (h > 0) {
      time = formatTime(h + ":" + m + ":" + s);
    } else {
      time = formatTime(m + ":" + s);
    }
    return time;
  };
  /**
   * 格式化时间显示，补零对齐
   * eg：2:4  -->  02:04
   * @param {string} value - 形如 h:m:s 的字符串
   */
  var formatTime = function (value) {
    var time = "";
    var s = value.split(':');
    var i = 0;
    for (; i < s.length - 1; i++) {
      time += s[i].length == 1 ? ("0" + s[i]) : s[i];
      time += ":";
    }
    time += s[i].length == 1 ? ("0" + s[i]) : s[i];
    return time;
  };

  var uncodeUtf16 = function (str) {
    var reg = /\&#.*?;/g;
    var result = str.replace(reg,function(char){
      var H,L,code;
      if(char.length == 9 ){
        code = parseInt(char.match(/[0-9]+/g));
        H = Math.floor((code-0x10000) / 0x400)+0xD800;
        L = (code - 0x10000) % 0x400 + 0xDC00;
        return unescape("%u"+H.toString(16)+"%u"+L.toString(16));
      }else{
        return char;
      }
    });
    return result;
  };

  var stopAllAudio = function (){
    var allAudioList = $(".content").find('audio');
    for (var i = 0; i < allAudioList.length; i++) {
      var audioItem = allAudioList[i];
      audioItem.pause();
      audioItem.currentTime = 0;
      $(audioItem).parent().find(".record-icon").attr("src","./res/images/icon/icon_record.png");
    }
  };

  //转菊花
  var showLoading = function () {
    $(".fullBg").removeClass("none");
    $(".loader").removeClass("none");
  };
  //隐藏菊花
  var hideLoading = function () {
    $(".fullBg").addClass("none");
    $(".loader").addClass("none");
  };

  return {
    init: init
  };
});
