// 主界面
;
define(function (require, exports, module) {
  'use strict';
  var util = require("util");
  var base = require("base");
  var databind = require("databind");
  var listView = require("listView");
  var router = require("pageRouter");
  var dialog = require("dialog");
  var constant = require("constant");
  var dom;
  var bookId;
  var examData;
  var topicIndex;
  var remainingTime;
  var countDownInterval;
  var pauseRemainingTime;

  var init = function () {
    bookId = base.getUrlParam("bookId");
    dom = $("#exam");
    router.init();
    initEvent();
    loadData();
  };

  //防止考试途中误触，重写安卓返回按钮。多一层提示
  var androidBackButtonEvent = function () {
    window._android_on_back_pressed = function() {
      dialog.loadDialog("dialog.confirmDialog", {
        params: {
          tips: "确认放弃本次考试？"
        },
        okFn: function() {
          $(".dialog-container").addClass("none");
          base.back();
        }
      }, "small");
      return false;
    }
  };

  var initEvent = function () {
    androidBackButtonEvent();
    calculateBgSize();

    //首次加载把头部弄成透明
    dom.find(".header").css("background-color", "transparent");
    dom.on("click", ".exam-cancel", function () {
      window.history.back();
    });
    dom.on("click", ".exam-start", function () {
      generateReadingExamTopicAccount(bookId);
    });
    //答题单选按钮事件
    dom.on("click", ".option-left", function () {
      dom.find(".select-radio-selected").addClass("none");
      dom.find(".select-radio-selected").removeClass("my-option-select");
      dom.find(".select-radio").removeClass("none");
      $(this).parents(".topic-option-item").find(".option-right").find(".select-radio-selected").removeClass("none").addClass("my-option-select");
      $(this).parents(".topic-option-item").find(".option-right").find(".select-radio").addClass("none");
    });
    dom.on("click", ".option-right", function () {
      dom.find(".select-radio-selected").addClass("none");
      dom.find(".select-radio-selected").removeClass("my-option-select");
      dom.find(".select-radio").removeClass("none");
      $(this).parents(".topic-option-item").find(".option-right").find(".select-radio-selected").removeClass("none").addClass("my-option-select");
      $(this).parents(".topic-option-item").find(".option-right").find(".select-radio").addClass("none");
    });
    //提交按钮
    dom.on("click", ".submit-button", function () {
      submitTopicOption();
    });
    //题目报错
    dom.on("click", ".topic-report-error", function () {
      pauseRemainingTime = remainingTime;
      window.clearInterval(countDownInterval);
      topicReportError();
    });

  };

  var loadData = function () {
  };

  var calculateBgSize = function () {
    var winWidth = 0;
    var winHeight = 0;
    // 获取窗口宽度
    if (window.innerWidth)
      winWidth = window.innerWidth;
    else if ((document.body) && (document.body.clientWidth))
      winWidth = document.body.clientWidth;
    // 获取窗口高度
    if (window.innerHeight)
      winHeight = window.innerHeight;
    else if ((document.body) && (document.body.clientHeight))
      winHeight = document.body.clientHeight;
    // 通过深入 Document 内部对 body 进行检测，获取窗口大小
    if (document.documentElement && document.documentElement.clientHeight && document.documentElement.clientWidth) {
      winHeight = document.documentElement.clientHeight;
      winWidth = document.documentElement.clientWidth;
    }
    var bgTopSize = winWidth * 0.9176; //由图片分辨率得出
    var bgBottomSize = winWidth * 0.6676; //由图片分辨率得出
    //撑开屏幕总高度
    // var newWinHeight = winHeight > bgTopSize + bgBottomSize ? winHeight : bgTopSize + bgBottomSize;
    var bgRepeat = winHeight - bgTopSize - bgBottomSize;
    //背景
    dom.find(".exam-bg").css("min-height", winHeight);
    dom.find(".exam-bg-top").css("min-height", bgTopSize);
    dom.find(".exam-bg-middle").css("top", (bgTopSize - 1));
    dom.find(".exam-bg-middle-img").css("height", bgRepeat);
    dom.find(".exam-bg-bottom").css("min-height", bgBottomSize);
    //如果背景图片一个屏幕容纳不下，截掉下面部分
    if (winHeight < bgTopSize + bgBottomSize) {
      dom.find(".exam-bg-bottom").css("top", bgTopSize - 1);
    }
    //计时器
    var clockWidth = winWidth * 0.28;
    var clockHeight = clockWidth * 1.05;
    dom.find(".exam-block").css("width", clockWidth);
    dom.find(".exam-block").css("height", clockHeight);
    //题目计数器
    var counterWidth = winWidth * 0.333;
    var counterHeight = winWidth * 0.35 / 2;
    var counterPositionLeft = (winWidth - counterWidth) / 2;
    var counterFontSize = counterWidth / 7;
    dom.find(".topic-counter").css("width", counterWidth);
    dom.find(".topic-counter").css("height", counterHeight);
    dom.find(".topic-counter").css("left", counterPositionLeft);
    dom.find(".topic-counter-font-size").css("font-size", counterFontSize);
    //倒计时数字提示 3、2、1
    var countDownWidth = winWidth * 0.15;
    var countDownHeight = winWidth * 0.15 * 1.5;
    var countDownPositionLeft = (winWidth - countDownWidth) / 2;
    var countDownFontSize = countDownWidth / 3.5;
    dom.find(".count-down").css("width", countDownWidth);
    dom.find(".count-down").css("height", countDownHeight);
    dom.find(".count-down").css("top", counterHeight + 10);
    dom.find(".count-down").css("left", countDownPositionLeft);
    dom.find(".block-font-size").css("font-size", countDownFontSize);
    dom.find(".block-time-font-size").css("font-size", countDownFontSize);
    dom.find(".block-unit-font-size").css("font-size", countDownFontSize - 1);
    dom.find(".block-time").css("padding-top", countDownHeight < 90 ? countDownHeight * 0.027 : countDownHeight * 0.08);
    //考试须知提示内容
    var noticeWidth = winWidth * 0.8 * 1.07;
    var noticeHeight = winWidth * 0.8;
    var noticePositionLeft = (winWidth - winWidth * 0.8 * 1.07) / 2;
    var noticePositionTop = (winHeight - winWidth * 0.8) / 2 - 42;
    dom.find(".exam-notice").css("width", noticeWidth);
    dom.find(".exam-notice").css("height", noticeHeight);
    dom.find(".exam-notice").css("left", noticePositionLeft);
    dom.find(".exam-notice").css("top", noticePositionTop);
    //按钮部分
    var buttonPositionWidth = noticeWidth * 1.05;
    var buttonPositionTop = noticePositionTop + noticeHeight + 50;
    var buttonPositionLeft = (winWidth - buttonPositionWidth) / 2;
    var buttonWidth = buttonPositionWidth * 0.40;
    var buttonHeight = buttonWidth * 0.40;
    var monkeyWidth = winWidth * 0.2;
    var monkeyHeight = winWidth * 0.2 * 1.42;
    dom.find(".exam-before-button-area").css("width", buttonPositionWidth);
    dom.find(".exam-before-button-area").css("left", buttonPositionLeft);
    dom.find(".exam-before-button-area").css("top", buttonPositionTop);
    dom.find(".exam-cancel").css("width", buttonWidth);
    dom.find(".exam-cancel").css("height", buttonHeight);
    dom.find(".exam-start").css("width", buttonWidth);
    dom.find(".exam-start").css("height", buttonHeight);
    dom.find(".submit-button").css("width", buttonWidth);
    dom.find(".submit-button").css("height", buttonHeight);
    dom.find(".monkey-image").css("width", monkeyWidth);
    dom.find(".monkey-image").css("height", monkeyHeight);
    dom.find(".monkey").css("top", -(monkeyHeight * 0.85));
    dom.find(".monkey").css("left", "10%");
    //考试区域
    var examAreaPositionTop = winHeight * 0.26;
    dom.find(".exam-ing-area").css("top", examAreaPositionTop);
    //答题区字体大小
    var examAreaWidth = dom.find(".topic-area").width();
    var examAreaPadding = examAreaWidth * 0.02;
    var topicTitleFontSize = parseInt(examAreaWidth / 16);
    dom.find(".topic-area").css("padding", examAreaPadding);
    dom.find(".topic-area").css("font-size", topicTitleFontSize);
    dom.find(".option-left-index").css("font-size", topicTitleFontSize - 1 + "px");
    dom.find(".option-left-index").css("line-height", topicTitleFontSize + 8 + "px");
    dom.find(".option-left-content").css("font-size", topicTitleFontSize - 1 + "px");
    dom.find(".option-left-content").css("line-height", topicTitleFontSize + 8 + "px");
    dom.find(".topic-option-radio").css("width", topicTitleFontSize + "px");
    dom.find(".topic-option-radio").css("height", topicTitleFontSize + "px");
    //答题区内容部分是否需要撑开
    var currentDisplayMaxCanUseHeight = winHeight - examAreaPositionTop;
    var buttonAreaHeight = dom.find(".button-area").height();
    var needHeight = dom.find(".exam-ing-area").height();
    //如果屏幕装不下考试区域时压缩考试区域让考试题目区域可以滚动
    if (needHeight >= currentDisplayMaxCanUseHeight) {
      var adaptiveHeight = (currentDisplayMaxCanUseHeight - buttonAreaHeight - (examAreaPadding * 2) - ($(".exam-ing-area").height() * 0.1) - 8);
      dom.find(".topic-area").css("height", adaptiveHeight * 0.95 + "px");
    }
  };

  //查询题库
  var generateReadingExamTopicAccount = function (bookId) {
    showLoading();
    databind.submit([], {
      action: "generateReadingExamTopicAccount",
      version: "v1.0",
      async:false,
      data: {
        bookId: bookId
      },
      success: function (data) {
        hideLoading();
        examData = data;
        var currentData = {};
        var array = [];
        array.push(data.datas[0]);
        currentData.datas = array;
        var html = juicer(dom.find("#topicTpl").html(), currentData);
        topicIndex = 1;
        dom.find(".exam-ing-area").html(html);
        dom.find(".topic-index").html(topicIndex);
        resetInterval();
        dom.find(".exam-before-need-none").removeClass("none");
        dom.find(".exam-need-none").addClass("none");
        calculateBgSize();
      },
      fail: function (error) {
        hideLoading();
      }
    });
  };

  //重置定时器
  var resetInterval = function () {
    dom.find(".block-time-content").removeClass("none");
    dom.find(".block-time-unit").removeClass("none");
    window.clearInterval(countDownInterval);
    remainingTime = 90;
    setInterval();
  };

  //定时器
  var setInterval = function () {
    countDownInterval = window.setInterval(function () {
      remainingTime = remainingTime - 1;
      showCountDownTip(remainingTime);
      if (remainingTime > 0) {
        dom.find(".block-time-content").html(remainingTime);
      } else {
        window.clearInterval(countDownInterval);
        showLoading();
        timeOutAutoSubmit();
      }
    }, 1000);
  };

  //3、2、1倒计时
  var showCountDownTip = function (remainingTime) {
    dom.find(".count-down-clean").addClass("none");
    switch (remainingTime) {
      case 3 :
        dom.find(".count-down-3").removeClass("none");
        break;
      case 2 :
        dom.find(".count-down-2").removeClass("none");
        break;
      case 1 :
        dom.find(".count-down-1").removeClass("none");
        break;
    }
  };

  //提交答案选项
  var submitTopicOption = function () {
    var examItem = dom.find(".my-option-select").parents(".topic-option-item");
    if (examItem == undefined || examItem.length == 0) {
      base.alert(1, "请选择答案");
      return
    }
    showLoading();
    databind.submit(examItem, {
      action: "judgeReadingExamTopicOptionAccount",
      version: "v1.0",
      data: {},
      success: function (data) {
        hideLoading();
        switch (data.datas[0].examState) {
          case 1:
            examPass(data);//闯关成功
            break;
          case 2:
            examFail(data.datas[0].nextCanExamDate);//闯关失败
            break;
          case 3:
            nextTopic();//继续答题
            break;
        }
      },
      fail: function (error) {
        hideLoading();
      }
    });
  };

  //答题超时自动提交
  var timeOutAutoSubmit = function () {
    var examItem = dom.find(".my-option-select").parents(".topic-option-item");
    if (examItem == undefined || examItem.length == 0){
      databind.submit([], {
        action: "judgeReadingExamTopicOptionAccount",
        version: "v1.0",
        data: {
          paperUuid:dom.find("input[name='paperUuid']")[0].value,
          topicId:dom.find("input[name='topicId']")[0].value,
          topicOptionId:0
        },
        success: function (data) {
          hideLoading();
          switch (data.datas[0].examState) {
            case 1:
              examPass(data.datas[0].reward);//闯关成功
              break;
            case 2:
              examFail(data.datas[0].nextCanExamDate);//闯关失败
              break;
            case 3:
              nextTopic();//继续答题
              break;
          }
        },
        fail: function (error) {
          hideLoading();
        }
      });
      return;
    }
    databind.submit(examItem, {
      action: "judgeReadingExamTopicOptionAccount",
      version: "v1.0",
      data: {},
      success: function (data) {
        hideLoading();
        switch (data.datas[0].examState) {
          case 1:
            examPass(data);//闯关成功
            break;
          case 2:
            examFail(data.datas[0].nextCanExamDate);//闯关失败
            break;
          case 3:
            nextTopic();//继续答题
            break;
        }
      },
      fail: function (error) {
        hideLoading();
      }
    });
  };

  var topicReportError = function () {
    var topicId = $(dom.find(".topic-option-item")[0]).find("input[name='topicId']").val();
    dialog.loadDialog("dialog.dialog-topic-report-error", {
      params: {
        tips: "题目有误？",
        topicId: topicId,
        reportErrorCallBack: reportErrorCallBack
      },
      okFn: function () {
        dialog.hideDialog();
      },
      closeFn: function () {
        setInterval();
        remainingTime = pauseRemainingTime;
      },
      test:function () {
        console.log("test");
      }
    }, "medium");
  };

  var reportErrorCallBack = function (topicId, errorType) {
    var topicId = $(dom.find(".topic-option-item")[0]).find("input[name='topicId']").val();
    showLoading();
    databind.submit([], {
      action: "readingTopicReportErrorAccount",
      version: "v1.0",
      data: {
        bookId: bookId,
        topicId: topicId,
        errorType: errorType
      },
      success: function (data) {
        base.alert(1, "报错成功");
        dialog.hideDialog();
        hideLoading();
      },
      fail: function (error) {
        hideLoading();
        base.alert(3, error.message);
      }
    });
  };

  var examPass = function (data) {
    window.clearInterval(countDownInterval);
    dialog.loadDialog("dialog.dialog-exam-pass", {
      params: {
        tips: "闯关成功",
        reward:data.datas[0].reward
      },
      okFn: function () {
        dialog.hideDialog();
        if (data.datas[0].isLevelUp) {
          setTimeout(function () {
            showLevelUpDialog(data.datas[0].level);
          }, 200);
        } else {
          window.history.back();
        }
      }
    }, "medium");
  };

  var examFail = function (nextCanExamDate) {
    window.clearInterval(countDownInterval);
    dialog.loadDialog("dialog.dialog-exam-fail", {
      params: {
        tips: "闯关失败",
        nextCanExamDate:nextCanExamDate
      },
      okFn: function () {
        dialog.hideDialog();
        window.history.back();
      }
    }, "medium");
  };

  var showLevelUpDialog = function (newLevel) {
    dialog.loadDialog("dialog.dialog-level-up", {
      params: {
        tips: "升级啦!",
        newLevel:newLevel
      },
      okFn: function () {
        dialog.hideDialog();
      },
    }, "large");
  };

  var nextTopic = function () {
    var currentData = {};
    var array = [];
    topicIndex = topicIndex + 1;
    array.push(examData.datas[topicIndex - 1]);
    currentData.datas = array;
    var html = juicer(dom.find("#topicTpl").html(), currentData);
    dom.find(".exam-ing-area").html(html);
    dom.find(".topic-index").html(topicIndex);
    resetInterval();
    calculateBgSize();
  };

  //转菊花
  var showLoading = function(){
    $(".fullBg").removeClass("none");
    $(".loader").removeClass("none");
  };
  //隐藏菊花
  var hideLoading = function(){
    $(".fullBg").addClass("none");
    $(".loader").addClass("none");
  };



  return {
    init: init
  };
});
